#include "wrap.h"

int Socket(int family, int type, int protocol){
    int             n;

    if ((n = socket(family, type, protocol)) < 0)
	err_sys("socket error");
    return(n);
}

void *Malloc(size_t size){
    void *ptr;

    
    if ((ptr = malloc(size)) == NULL)
	err_sys("malloc error");
    return(ptr);
}

void *Reallocf(void *ptr,size_t size){
    void *newptr;

    if ((newptr = reallocf(ptr,size)) == NULL)
	err_sys("reallocf error");
    return(newptr);
}

void *Calloc(size_t number,size_t size){
    void *newptr;

    if ((newptr = calloc(number,size)) == NULL)
	err_sys("calloc error");
    return(newptr);
}

int Write(int fd, void *ptr, size_t nbytes){
        if (write(fd, ptr, nbytes) != nbytes) {
		err_ret("write failed");
		return errno;
	}
	return 0;
}

ssize_t Read(int fd, void *ptr, size_t nbytes){
        ssize_t         n;
        
        if ( (n = read(fd, ptr, nbytes)) == -1)
                err_sys("read error");
        return(n);
}

int Fork() {
    int pid;
    if (( pid=fork())<0) 
	err_sys("Fork failed");
    return pid;
}


int Kevent(int kq, const struct kevent *cl, int nc, struct kevent *el, int nev, const struct timespec *to){
    int n;

    if ((n=kevent(kq,cl,nc,el,nev,to)) <0 )
	err_sys("kqueue event failed");
    return n;
}

int Kqueue() {
    int n;
   
    if ((n=kqueue()) <0 )
	err_sys("creating kqueue failed");
    return n;
}

int Bind(int s, const struct sockaddr *addr, socklen_t addrlen){
    int n;

    if ((n=bind(s,addr,addrlen))<0)
	err_sys("bind failed");
    return n;
}
int Listen(int s,int backlog) {
    int n;

    if((n=listen(s,backlog))<0)
	err_sys("listen failed");
    return n;
}

int Accept(int s, struct sockaddr *addr, socklen_t *addrlen) {
    int n;

    if((n=accept(s,addr,addrlen))==-1)
	err_sys("accept failed");
    return n;
}

int Connect(int s, const struct sockaddr *name, socklen_t namelen){
    int n;
    if((n=connect(s,name,namelen))==-1)
	err_sys("connect failed");
    return n;
}

int Gettimeofday(struct timeval *tp){
    int n;
    if((n=gettimeofday(tp, NULL)) != 0)
	err_sys("gettimeofday failed");
    return n;
}